import requests,urllib3,time
urllib3.disable_warnings()

class DownloadedFile:
    def __init__(self, link: str):
        self.link = link

    def save(self, path: str):
        """Downloads compressed video
        `path`: Path to save your video.
        ```py
        file = ac.compress_video("./video.mp4")
        file.save("./output.mp4")
        ```
        """
        binaries = requests.get(self.link).content
        open(path, "wb").write(binaries)

class AsposeCompressor:
    def __init__(self):
        """
        ```py
        ac = AsposeCompressor()
        ```
        """

    def compress_video(self, path_to_file: str) -> str:
        """Returns the download link for the compressed file
        ```py
        ac = AsposeCompressor()
        file = ac.compress_video("./video.mp4")
        ```
        """
        self.files = {
            '1': open(path_to_file, 'rb'),
            'VideoFormat': (None, 'mp4'),
        }

        print("[!] Compressing video")
        response = requests.post('https://api.products.aspose.app/video/compress/api/compress', files=self.files, verify=False)
        file_request_id = response.json()["Data"]["FileRequestId"]
        params = {
            'fileRequestId': file_request_id,
        }
        response = None

        print("[!] Fetching download link")
        response = requests.get(
            'https://api.products.aspose.app/video/compress/api/compress/HandleStatus',
            params=params,
            verify=False,
        )

        while response.json()["Data"]["DownloadLink"] == None:
            response = requests.get(
                'https://api.products.aspose.app/video/compress/api/compress/HandleStatus',
                params=params,
                verify=False,
            )
            time.sleep(5)
        print("[!] Compression finished")
        return DownloadedFile(response.json()["Data"]["DownloadLink"])


import setuptools

with open("README.md", "r", encoding="utf-8") as fh:
    long_description = fh.read()

setup_info = {
    "name": "aspose_compressor",
    "version": "0.0.2",
    "author": "CantCode023",
    "author_email": "cantcode023@gmail.com",
    "description": "Compress video with 100% compress size and no quality loss with only 3 lines of code.",
    "long_description": long_description,
    "long_description_content_type": "text/markdown",
    "url": "https://github.com/CantCode023/aspose_compressor",
    "packages": setuptools.find_packages(),
    "install_requires": ["requests", "urllib3"],
    "classifiers": [
        "Programming Language :: Python :: 3",
    ],
    "python_requires": '>=3.7'
}


setuptools.setup(**setup_info)